@@ -13,12 +13,12 @@ from control import *
 from aircraft import *
 from xfoil_visc import *
 from aerodynamic_output import *
-from toolkit import *
+from pytoolkit import *
 tdy=LoveUpdate.getdate()
 if not os.path.exists('updatestat.lup'):
     lupfile=open('updatestat.lup', 'wb')
     statusdict={'lastupdate':tdy, 'updateme':True}
-    _=LoveUpdate.update('LoveUpdate', statusdict['lastupdate']-1)
+    _=LoveUpdate.update('LoveUpdate', '')
     pickle.dump(statusdict, lupfile)
     lupfile.close()
 lupfile=open('updatestat.lup', 'rb')
