@@ -10,7 +10,6 @@ from mpl_toolkits import mplot3d
 import scipy.sparse as sps
 import time as tm
 
-import toolkit
 from utils import *
 from body import *
 from control import *
@@ -130,7 +129,7 @@ class wing_quadrant: #wing region between two airfoil sections
     def trim_bybody(self, contactbody, sectside=2, tolerance=0.00005):
         #trim wing section by body contact, for abutment
         if sectside==2:
-            ps=self.sect1.points
+            ps=self.sect2.points
             us=self.sect2.points-self.sect1.points
             for i in range(np.size(self.sect2.points, 0)):
                 newpt, errorcode=contactbody.find_body_intersect(ps[i, :], us[i, :], tolerance=tolerance)
@@ -140,9 +139,9 @@ class wing_quadrant: #wing region between two airfoil sections
                 else:
                     self.sect2.points[i, :]=newpt
         else:
-            ps=self.sect2.points
+            ps=self.sect1.points
             us=self.sect1.points-self.sect2.points
-            for i in range(np.size(self.sect2.points, 0)):
+            for i in range(np.size(self.sect1.points, 0)):
                 newpt, errorcode=contactbody.find_body_intersect(ps[i, :], us[i, :], tolerance=tolerance)
                 if errorcode:
                     print('An error has been detected while trimming a wing section to a fuselage. Please check geometry to verify whether all requested intersections are possible,', \
@@ -377,7 +376,7 @@ class wing_quadrant: #wing region between two airfoil sections
         Mtosys=np.vstack((u, v, w))
         return Mtosys.T@(np.array([[0.0, 0.0, 1.0], \
             [0.0, 0.0, 0.0], \
-                [-1.0, 0.0, 0.0]]))@Mtosys
+                [-1.0, 0.0, 0.0]]))@Mtosys*np.pi/180
     def design_derivs(self, sectside=1): #calculate derivatives for posisions and normal vectors by the incidence of each section (identified in sectside kwarg)
         panrs=np.zeros((len(self.paninds), 3))
         panns=np.zeros((len(self.paninds), 3))
@@ -673,7 +672,7 @@ class wing:
             dCm+=dCm_quad
             dCn+=dCn_quad
         return dCX, dCY, dCZ, dCl, dCm, dCn
-    def calc_design_dFM(self, section=0, Uinf=1.0, rho=1.225, CG=np.zeros(3)): #section: index between 0 and len(self.wingquads) to indicate the section to derivate coefficients based on
+    def calc_design_dFM(self, section=0, Uinf=1.0, rho=1.225, CG=np.zeros(3), M=0.0, gamma=1.4): #section: index between 0 and len(self.wingquads) to indicate the section to derivate coefficients based on
         #returns derivatives of forces and moments
         drdinc=np.zeros((self.sld.npanels, 3))
         dndinc=np.zeros((self.sld.npanels, 3))
@@ -684,7 +683,7 @@ class wing:
         dnvvdinc=np.zeros(self.sld.npanels) #derivative of normal velocity component
         for i in range(self.sld.npanels):
             dnvvdinc[i]=self.sld.vbar[i, :]@dndinc[i, :]
-        dCps=self.sld.calc_derivative_dn(Uinf=Uinf, dndksi=dnvvdinc)
+        dCps=self.sld.calc_derivative_dn(Uinf=Uinf, dndksi=dnvvdinc, M=M, gamma=gamma)
         dFs=np.zeros((self.sld.npanels, 3))
         dMs=np.zeros((self.sld.npanels, 3))
         for i in range(self.sld.npanels):
